package expressionprog;

/**
 * A program item that represents one of the binary operators +, -, *, /, or ^.
 * The operands are popped from the stack, the operation is applied, and the
 * result is pushed back onto the stack.
 */
public class BinOp extends ProgramItem {
	
	private final char operator;
	
	public BinOp(char op) {
		if (op != '+' && op != '-' && op != '*' && op != '/' && op != '^')
			throw new IllegalArgumentException("Operator must be +, -, *, /, or ^.");
		operator = op;
	}
	
	/**
	 * Returns the operator that this program item represents.
	 */
	public char getOperator() {
		return operator;
	}

	/**
	 * Returns a string describing the action of this program item on a stack.
	 */
	public String toString() {
		return "Apply binary operator " + operator;
	}

}
